# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

#' Report CPU Architecture and Compiler
#'
#' @return A constant direct created at compile-time describing
#' the extent of AVX instructions (512 bit, 128 bit, or none)
#' and compiler use where currently recognised are MSC (unlikely
#' for R), GCC, Clang, or \sQuote{other}.
getArchictectureStatus <- function() {
    .Call(`_RcppAnnoy_getArchictectureStatus`)
}

.annoy_version <- function() {
    .Call(`_RcppAnnoy_annoy_version`)
}

